# io.swagger.client - Kotlin client library for HRRR Vert Forecast - A Weather Source API

## Requires

* Kotlin 1.4.30
* Gradle 5.3

## Build

First, create the gradle wrapper script:

```
gradle wrapper
```

Then, run:

```
./gradlew check assemble
```

This runs all tests and packages the library.

## Features/Implementation Notes

* Supports JSON inputs/outputs, File inputs, and Form inputs.
* Supports collection formats for query parameters: csv, tsv, ssv, pipes.
* Some Kotlin and Java types are fully qualified to avoid conflicts with types defined in Swagger definitions.
* Implementation of ApiClient is intended to reduce method counts, specifically to benefit Android targets.

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://hrrrvertforecast.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OnpointsApi* | [**onpointsOnpointIdHeightHeightQuarterhoursGet**](docs/OnpointsApi.md#onpointsonpointidheightheightquarterhoursget) | **GET** /onpoints/{onpointId}/height/{height}/quarterhours | The complete vertically interpolated quarterhourly HRRR forecast for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHeightHeightQuarterhoursTimestampGet**](docs/OnpointsApi.md#onpointsonpointidheightheightquarterhourstimestampget) | **GET** /onpoints/{onpointId}/height/{height}/quarterhours/{timestamp} | A quarterhour of vertically interpolated HRRR forecast data for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHeightHeightQuarterhoursTimestampStarttimestampEndGet**](docs/OnpointsApi.md#onpointsonpointidheightheightquarterhourstimestampstarttimestampendget) | **GET** /onpoints/{onpointId}/height/{height}/quarterhours/{timestampStart},{timestampEnd} | A contiguous range of vertically interpolated quarterhourly HRRR forecast data for an OnPoint™ point.
*PointsApi* | [**pointsLatitudelongitudeHeightHeightQuarterhoursGet**](docs/PointsApi.md#pointslatitudelongitudeheightheightquarterhoursget) | **GET** /points/{latitude},{longitude}/height/{height}/quarterhours | The complete vertically interpolated quarterhourly HRRR forecast for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHeightHeightQuarterhoursTimestampGet**](docs/PointsApi.md#pointslatitudelongitudeheightheightquarterhourstimestampget) | **GET** /points/{latitude},{longitude}/height/{height}/quarterhours/{timestamp} | A quarterhour of vertically interpolated HRRR forecast data for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHeightHeightQuarterhoursTimestampStarttimestampEndGet**](docs/PointsApi.md#pointslatitudelongitudeheightheightquarterhourstimestampstarttimestampendget) | **GET** /points/{latitude},{longitude}/height/{height}/quarterhours/{timestampStart},{timestampEnd} | A contiguous range of vertically interpolated quarterhourly HRRR forecast data for a Latitude/Longitude point.

<a name="documentation-for-models"></a>
## Documentation for Models

 - [io.swagger.client.models.BoundingPoints](docs/BoundingPoints.md)
 - [io.swagger.client.models.BoundingPointsInner](docs/BoundingPointsInner.md)
 - [io.swagger.client.models.Cape](docs/Cape.md)
 - [io.swagger.client.models.Cin](docs/Cin.md)
 - [io.swagger.client.models.CldCvr](docs/CldCvr.md)
 - [io.swagger.client.models.CountryCode](docs/CountryCode.md)
 - [io.swagger.client.models.CountryName](docs/CountryName.md)
 - [io.swagger.client.models.DewPt](docs/DewPt.md)
 - [io.swagger.client.models.Distance](docs/Distance.md)
 - [io.swagger.client.models.Elevation](docs/Elevation.md)
 - [io.swagger.client.models.ErrorObj](docs/ErrorObj.md)
 - [io.swagger.client.models.FeelsLike](docs/FeelsLike.md)
 - [io.swagger.client.models.FieldListHourObj](docs/FieldListHourObj.md)
 - [io.swagger.client.models.Fields](docs/Fields.md)
 - [io.swagger.client.models.Grid](docs/Grid.md)
 - [io.swagger.client.models.HailSize](docs/HailSize.md)
 - [io.swagger.client.models.HeatIndex](docs/HeatIndex.md)
 - [io.swagger.client.models.HrrrForecastHourArr](docs/HrrrForecastHourArr.md)
 - [io.swagger.client.models.HrrrForecastHourObj](docs/HrrrForecastHourObj.md)
 - [io.swagger.client.models.HrrrForecastOnpointHourObj](docs/HrrrForecastOnpointHourObj.md)
 - [io.swagger.client.models.HrrrForecastPointHourObj](docs/HrrrForecastPointHourObj.md)
 - [io.swagger.client.models.Latitude](docs/Latitude.md)
 - [io.swagger.client.models.Longitude](docs/Longitude.md)
 - [io.swagger.client.models.MslPres](docs/MslPres.md)
 - [io.swagger.client.models.OnpointId](docs/OnpointId.md)
 - [io.swagger.client.models.OnpointObj](docs/OnpointObj.md)
 - [io.swagger.client.models.PointObj](docs/PointObj.md)
 - [io.swagger.client.models.Precip](docs/Precip.md)
 - [io.swagger.client.models.Pres](docs/Pres.md)
 - [io.swagger.client.models.RadSolar](docs/RadSolar.md)
 - [io.swagger.client.models.RadSolarDirect](docs/RadSolarDirect.md)
 - [io.swagger.client.models.RelHum](docs/RelHum.md)
 - [io.swagger.client.models.Snowfall](docs/Snowfall.md)
 - [io.swagger.client.models.SnowfallKuchera](docs/SnowfallKuchera.md)
 - [io.swagger.client.models.SpcHum](docs/SpcHum.md)
 - [io.swagger.client.models.SubdivCode](docs/SubdivCode.md)
 - [io.swagger.client.models.SubdivName](docs/SubdivName.md)
 - [io.swagger.client.models.Temp](docs/Temp.md)
 - [io.swagger.client.models.Timestamp](docs/Timestamp.md)
 - [io.swagger.client.models.TimestampEnd](docs/TimestampEnd.md)
 - [io.swagger.client.models.TimestampInit](docs/TimestampInit.md)
 - [io.swagger.client.models.TimestampRangeObj](docs/TimestampRangeObj.md)
 - [io.swagger.client.models.TimestampStart](docs/TimestampStart.md)
 - [io.swagger.client.models.Timezone](docs/Timezone.md)
 - [io.swagger.client.models.WetBulb](docs/WetBulb.md)
 - [io.swagger.client.models.WindChill](docs/WindChill.md)
 - [io.swagger.client.models.WindDir](docs/WindDir.md)
 - [io.swagger.client.models.WindSpd](docs/WindSpd.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="ApiKeyAuth"></a>
### ApiKeyAuth


