/**
 * HRRR Vert Forecast - A Weather Source API
 * Quarterhourly vertically interpolated forecast data from the HRRR model for latitude/longitude points and Onpoint IDs. Quarterhourly forecast goes out 18 hours and is available in 15 minute increments. The Weather Source HRRR Forecast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis.    **IMPORTANT:** To authenticate to the Weather Source HRRR Vert Forecast API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.   
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
package io.swagger.client.apis

import io.swagger.client.models.ErrorObj
import io.swagger.client.models.HrrrForecastOnpointHourObj

import io.swagger.client.infrastructure.*

class OnpointsApi(basePath: kotlin.String = "https://hrrrvertforecast.weathersourceapis.com/v2") : ApiClient(basePath) {

    /**
     * The complete vertically interpolated quarterhourly HRRR forecast for an OnPoint™ point.
     * Returns the complete set of vertically interpolated HRRR forecast data for an OnPoint™ point.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param onpointId An OnPoint™ ID. 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, snowfall, snowfallKuchera, hailSize)* * allPres *(mslPres, pres)* * allRad *(radSolar, radSolarDirect)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windSpd)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  
     * @param height The height in meters at which to vertically interpolate. The height MUST be in meters, even if selecting IMPERIAL unit type. 
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return HrrrForecastOnpointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun onpointsOnpointIdHeightHeightQuarterhoursGet(onpointId: kotlin.Int, fields: kotlin.Array<kotlin.String>, height: java.math.BigDecimal, unitScale: kotlin.String? = null): HrrrForecastOnpointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/onpoints/{onpointId}/height/{height}/quarterhours".replace("{" + "onpointId" + "}", "$onpointId").replace("{" + "height" + "}", "$height"), query = localVariableQuery
        )
        val response = request<HrrrForecastOnpointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as HrrrForecastOnpointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * A quarterhour of vertically interpolated HRRR forecast data for an OnPoint™ point.
     * Returns a single quarterhour of vertically interpolated HRRR forecast data for an OnPoint™ point. The provided timestamp must exist within the current valid 18 hour forecast range.  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param onpointId An OnPoint™ ID. 
     * @param timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, snowfall, snowfallKuchera, hailSize)* * allPres *(mslPres, pres)* * allRad *(radSolar, radSolarDirect)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windSpd)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  
     * @param height The height in meters at which to vertically interpolate. The height MUST be in meters, even if selecting IMPERIAL unit type. 
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return HrrrForecastOnpointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun onpointsOnpointIdHeightHeightQuarterhoursTimestampGet(onpointId: kotlin.Int, timestamp: java.time.LocalDateTime, fields: kotlin.Array<kotlin.String>, height: java.math.BigDecimal, unitScale: kotlin.String? = null): HrrrForecastOnpointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/onpoints/{onpointId}/height/{height}/quarterhours/{timestamp}".replace("{" + "onpointId" + "}", "$onpointId").replace("{" + "timestamp" + "}", "$timestamp").replace("{" + "height" + "}", "$height"), query = localVariableQuery
        )
        val response = request<HrrrForecastOnpointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as HrrrForecastOnpointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * A contiguous range of vertically interpolated quarterhourly HRRR forecast data for an OnPoint™ point.
     * Returns a contiguous range of vertically interpolated quarterhourly HRRR forecast data for an OnPoint™ point. The provided timestamps must exist within the current valid 18 hour forecast range.  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param onpointId An OnPoint™ ID. 
     * @param timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. 
     * @param timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, snowfall, snowfallKuchera, hailSize)* * allPres *(mslPres, pres)* * allRad *(radSolar, radSolarDirect)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windSpd)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  
     * @param height The height in meters at which to vertically interpolate. The height MUST be in meters, even if selecting IMPERIAL unit type. 
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return HrrrForecastOnpointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun onpointsOnpointIdHeightHeightQuarterhoursTimestampStarttimestampEndGet(onpointId: kotlin.Int, timestampStart: java.time.LocalDateTime, timestampEnd: java.time.LocalDateTime, fields: kotlin.Array<kotlin.String>, height: java.math.BigDecimal, unitScale: kotlin.String? = null): HrrrForecastOnpointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/onpoints/{onpointId}/height/{height}/quarterhours/{timestampStart},{timestampEnd}".replace("{" + "onpointId" + "}", "$onpointId").replace("{" + "timestampStart" + "}", "$timestampStart").replace("{" + "timestampEnd" + "}", "$timestampEnd").replace("{" + "height" + "}", "$height"), query = localVariableQuery
        )
        val response = request<HrrrForecastOnpointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as HrrrForecastOnpointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
}
