/**
 * HRRR Vert Forecast - A Weather Source API
 * Quarterhourly vertically interpolated forecast data from the HRRR model for latitude/longitude points and Onpoint IDs. Quarterhourly forecast goes out 18 hours and is available in 15 minute increments. The Weather Source HRRR Forecast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis.    **IMPORTANT:** To authenticate to the Weather Source HRRR Vert Forecast API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.   
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
package io.swagger.client.apis

import io.swagger.client.models.ErrorObj
import io.swagger.client.models.HrrrForecastPointHourObj

import io.swagger.client.infrastructure.*

class PointsApi(basePath: kotlin.String = "https://hrrrvertforecast.weathersourceapis.com/v2") : ApiClient(basePath) {

    /**
     * The complete vertically interpolated quarterhourly HRRR forecast for a Latitude/Longitude point.
     * Returns the complete vertically interpolated set of HRRR forecast data for a Latitude/Longitude point.  *Alternatively using a query that specificies just the quarterhours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param height The height in meters at which to vertically interpolate. The height MUST be in meters, even if selecting IMPERIAL unit type. 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, snowfall, snowfallKuchera, hailSize)* * allPres *(mslPres, pres)* * allRad *(radSolar, radSolarDirect)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windSpd)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return HrrrForecastPointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHeightHeightQuarterhoursGet(latitude: kotlin.Float, longitude: kotlin.Float, height: java.math.BigDecimal, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): HrrrForecastPointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/height/{height}/quarterhours".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "height" + "}", "$height"), query = localVariableQuery
        )
        val response = request<HrrrForecastPointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as HrrrForecastPointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * A quarterhour of vertically interpolated HRRR forecast data for a Latitude/Longitude point.
     * Returns a single quarterhour of vertically interpolated HRRR forecast data for a Latitude/Longitude point. The provided timestamp must exist within the current valid 18 hour forecast range.  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. 
     * @param height The height in meters at which to vertically interpolate. The height MUST be in meters, even if selecting IMPERIAL unit type. 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, snowfall, snowfallKuchera, hailSize)* * allPres *(mslPres, pres)* * allRad *(radSolar, radSolarDirect)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windSpd)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return HrrrForecastPointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHeightHeightQuarterhoursTimestampGet(latitude: kotlin.Float, longitude: kotlin.Float, timestamp: java.time.LocalDateTime, height: java.math.BigDecimal, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): HrrrForecastPointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/height/{height}/quarterhours/{timestamp}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "timestamp" + "}", "$timestamp").replace("{" + "height" + "}", "$height"), query = localVariableQuery
        )
        val response = request<HrrrForecastPointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as HrrrForecastPointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * A contiguous range of vertically interpolated quarterhourly HRRR forecast data for a Latitude/Longitude point.
     * Returns a contiguous range of vertically interpolated quarterhourly HRRR forecast data for a Latitude/Longitude point. The provided timestamps must exist within the current valid 18 hour forecast range.  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. 
     * @param timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. 
     * @param height The height in meters at which to vertically interpolate. The height MUST be in meters, even if selecting IMPERIAL unit type. 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, snowfall, snowfallKuchera, hailSize)* * allPres *(mslPres, pres)* * allRad *(radSolar, radSolarDirect)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windSpd)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return HrrrForecastPointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHeightHeightQuarterhoursTimestampStarttimestampEndGet(latitude: kotlin.Float, longitude: kotlin.Float, timestampStart: java.time.LocalDateTime, timestampEnd: java.time.LocalDateTime, height: java.math.BigDecimal, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): HrrrForecastPointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/height/{height}/quarterhours/{timestampStart},{timestampEnd}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "timestampStart" + "}", "$timestampStart").replace("{" + "timestampEnd" + "}", "$timestampEnd").replace("{" + "height" + "}", "$height"), query = localVariableQuery
        )
        val response = request<HrrrForecastPointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as HrrrForecastPointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
}
